@@ -33,7 +33,7 @@ sub init {
 	$init = Mojo::Pg::Migrations->new(pg => $db);
 	$init->name('init');
 	$init->from_data();
-	#$code->migrate(0);
+	$code->migrate(0);
 	$init->migrate() or return 0;
 	$code->migrate() or return 0;
 	if(defined($config->get("adminuser")) && defined($config->get("adminpw"))) {
@@ -1048,6 +1048,104 @@ DROP TABLE config_overrides;
 ALTER TABLE users ADD CONSTRAINT users_email_unique UNIQUE (email);
 -- 19 down
 ALTER TABLE users DROP CONSTRAINT users_email_unique;
+-- 20 up
+CREATE TYPE talkstate_new AS ENUM (
+    'waiting_for_files',
+    'cutting',
+    'generating_previews',
+    'notification',
+    'preview',
+    'transcoding',
+    'uploading',
+    'publishing',
+    'announcing',
+    'done',
+    'broken',
+    'needs_work',
+    'lost',
+    'ignored'
+);
+ALTER TABLE talks ALTER state DROP DEFAULT;
+ALTER TABLE talks ALTER state TYPE talkstate_new USING(state::varchar)::talkstate_new;
+ALTER TABLE talks ALTER state SET DEFAULT 'waiting_for_files';
+DROP TYPE talkstate;
+ALTER TYPE talkstate_new RENAME TO talkstate;
+-- 20 down
+CREATE TYPE talkstate_new AS ENUM (
+    'waiting_for_files',
+    'cutting',
+    'generating_previews',
+    'notification',
+    'preview',
+    'transcoding',
+    'uploading',
+    'announcing',
+    'done',
+    'broken',
+    'needs_work',
+    'lost',
+    'ignored'
+);
+ALTER TABLE talks ALTER state DROP DEFAULT;
+ALTER TABLE talks ALTER state TYPE talkstate_new USING(state::varchar)::talkstate_new;
+ALTER TABLE talks ALTER state SET DEFAULT 'waiting_for_files';
+DROP TYPE talkstate;
+ALTER TYPE talkstate_new RENAME TO talkstate;
+-- 21 up
+ALTER TABLE talks ADD flags json;
+-- 21 down
+ALTER TABLE talks DROP flags;
+-- 22 up
+CREATE TYPE talkstate_new AS ENUM (
+    'waiting_for_files',
+    'cutting',
+    'generating_previews',
+    'notification',
+    'preview',
+    'transcoding',
+    'uploading',
+    'publishing',
+    'announcing',
+    'done',
+    'injecting',
+    'broken',
+    'needs_work',
+    'lost',
+    'ignored'
+);
+ALTER TABLE talks ALTER state DROP DEFAULT;
+ALTER TABLE talks ALTER state TYPE talkstate_new USING(state::varchar)::talkstate_new;
+ALTER TABLE talks ALTER state SET DEFAULT 'waiting_for_files';
+DROP TYPE talkstate;
+ALTER TYPE talkstate_new RENAME TO talkstate;
+-- 22 down
+CREATE TYPE talkstate_new AS ENUM (
+    'waiting_for_files',
+    'cutting',
+    'generating_previews',
+    'notification',
+    'preview',
+    'transcoding',
+    'uploading',
+    'publishing',
+    'announcing',
+    'done'
+    'broken'
+    'needs_work',
+    'lost',
+    'ignored'
+);
+ALTER TABLE talks ALTER state DROP DEFAULT;
+ALTER TABLE talks ALTER state TYPE talkstate_new USING(state::varchar)::talkstate_new;
+ALTER TABLE talks ALTER state SET DEFAULT 'waiting_for_files';
+DROP TYPE talkstate;
+ALTER TYPE talkstate_new RENAME TO talkstate;
+-- 23 up
+ALTER TABLE raw_files ADD CONSTRAINT unique_filename UNIQUE(filename);
+ALTER TABLE talks ALTER flags TYPE jsonb;
+-- 23 down
+ALTER TABLE raw_files DROP CONSTRAINT unique_filename;
+ALTER TABLE talks ALTER flags TYPE json;
 @@ code
 -- 1 up
 CREATE VIEW last_room_files AS
@@ -1455,3 +1553,88 @@ BEGIN
             OR (talks.endtime + start_off + end_off + '00:20:00'::interval) >= raw_files.starttime AND (talks.endtime + start_off + end_off + '00:20:00'::interval) <= raw_files.endtime
             OR (talks.endtime + start_off + end_off) <= raw_files.starttime AND (talks.endtime + start_off + end_off + '00:20:00'::interval) >= raw_files.endtime);
 END $_$;
+-- 3 up
+CREATE OR REPLACE FUNCTION state_next(talkstate) RETURNS talkstate
+    LANGUAGE plpgsql
+    AS $_$
+DECLARE
+  enumvals talkstate[];
+  startval ALIAS FOR $1;
+BEGIN
+  IF startval = 'injecting' THEN
+    return 'generating_previews'::talkstate;
+  ELSE
+    IF startval >= 'done' THEN
+      return startval;
+    ELSE
+      enumvals := enum_range(startval, NULL);
+      return enumvals[2];
+    END IF;
+  END IF;
+END $_$;
+-- 3 down
+CREATE OR REPLACE FUNCTION state_next(talkstate) RETURNS talkstate
+    LANGUAGE plpgsql
+    AS $_$
+declare
+  enumvals talkstate[];
+  startval alias for $1;
+begin
+  enumvals := enum_range(startval, NULL);
+  return enumvals[2];
+end $_$;
+-- 4 up
+DROP VIEW talk_list;
+CREATE VIEW talk_list AS
+ SELECT talks.id,
+    talks.event AS eventid,
+    events.name AS event,
+    events.outputdir AS event_output,
+    rooms.name AS room,
+    rooms.outputname AS room_output,
+    speakerlist(talks.id) AS speakers,
+    talks.title AS name,
+    talks.nonce,
+    talks.slug,
+    talks.starttime,
+    talks.endtime,
+    talks.state,
+    talks.progress,
+    talks.comments,
+    rooms.id AS roomid,
+    talks.prelen,
+    talks.postlen,
+    talks.subtitle,
+    talks.apologynote,
+    tracks.name AS track
+   FROM rooms
+     LEFT JOIN talks ON rooms.id = talks.room
+     LEFT JOIN events ON talks.event = events.id
+     LEFT JOIN tracks ON talks.track = tracks.id;
+-- 4 down
+DROP VIEW talk_list;
+CREATE VIEW talk_list AS
+ SELECT talks.id,
+    talks.event AS eventid,
+    events.name AS event,
+    rooms.name AS room,
+    rooms.outputname AS room_output,
+    speakerlist(talks.id) AS speakers,
+    talks.title AS name,
+    talks.nonce,
+    talks.slug,
+    talks.starttime,
+    talks.endtime,
+    talks.state,
+    talks.progress,
+    talks.comments,
+    rooms.id AS roomid,
+    talks.prelen,
+    talks.postlen,
+    talks.subtitle,
+    talks.apologynote,
+    tracks.name AS track
+   FROM rooms
+     LEFT JOIN talks ON rooms.id = talks.room
+     LEFT JOIN events ON talks.event = events.id
+     LEFT JOIN tracks ON talks.track = tracks.id;
